@@ -46,14 +46,14 @@ class reminder():
             finally:
                 if os.path.exists('.emailreminder_'+str(self.ppid)):
                     os.remove('.emailreminder_'+str(self.ppid))
-                    self.post(error=error)
+                    self.post(error=error, result=result)
                 if error == None:
                     return result
                 else:
                     raise e_copy
         return do
 
-    def post(self, error=None):
+    def post(self, error=None, result=None):
         session = requests.session()
         session.headers = {'User-Agent':'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                 'Chrome/51.0.2704.63 Safari/537.36','Referer':self.url}
@@ -61,6 +61,8 @@ class reminder():
         token = session.cookies.get('csrftoken')
         self.data['csrfmiddlewaretoken'] = token
         self.data['Ppid'] = self.ppid
+        if isinstance(result, str):
+            self.data['result'] = result
         self.post_error(error)
         self.post_time_cost()
         files = self.post_files()
